@@ -10,8 +10,14 @@ tarVersion = "V20210909"
 VersionDetail = "当前版本:" + tarVersion + """
 ---------------------------版本更新信息----------------------------
 
+可调用方法的API文档请访问:http://www.chuangfeigu.com:9900/web/#/64?page_id=1189
+
 V20210909:
 1.使用新的框架来实现旧的api
+
+V20220627:
+1.添加API说明
+
 ------------------------------------------------------------------
 """
 
@@ -86,12 +92,34 @@ class MCarDriver(BaseDriver, CarDict):
                                 prior=False)
 
     def setWaitTime(self, wait_recv_time=1):
+        """设置查询指令的响应等待时间.
+
+        Note:
+            该参数为全局变量.影响查询类方法的执行速度和成功率.
+            一般情况下,响应等待时间越久,执行速度越慢,成功率越高.
+            应根据实际的网络状况来谨慎配置.
+            不建议设置到0.5以下.
+
+        Args:
+            wait_recv_time (float, optional): 等待时间,单位:秒. Defaults to 1.
+
+        """
+        if wait_recv_time < 0:
+            LOGGER.logger.error(f"Parameter setting error!")
+            return False
         self.wait_time = wait_recv_time
 
     def getVersion(self):
+        """获取当前驱动的版本信息.
+
+        Returns:
+            Str: 当前驱动的版本号.
+        """
         return tarVersion
 
     def showVersion(self):
+        """打印历史版本的更新记录
+        """
         print(VersionDetail)
 
     def cnvHexArrayToHex(self, hex_array=None, scale=16):
@@ -145,11 +173,19 @@ class MCarDriver(BaseDriver, CarDict):
 
     def turnLeftOrigin(self):
         """小车原地左转
+
+         Note:
+            自动模式下,小车会向左转一个小角度，然后探头会进入找黑色模式，找到黑色即可停止，然后恢复到正常循迹模式
+        
         """
         self.excuteOrderRightAway("原地左转")
 
     def turnRightOrigin(self):
         """小车原地右转
+
+         Note:
+            自动模式下,小车会向右转一个小角度，然后探头会进入找黑色模式，找到黑色即可停止，然后恢复到正常循迹模式
+        
         """
         self.excuteOrderRightAway("原地右转")
 
@@ -769,7 +805,7 @@ class MCarDriver(BaseDriver, CarDict):
     def getCardNum(self):
         if self.refreshStatus() is False:
             return False
-        return self.car_status["车速"]
+        return self.car_status["卡号"]
 
     def getCarMode(self):
         if self.refreshStatus() is False:
